@@ -1,8 +1,14 @@
+from __future__ import division, absolute_import, print_function
+
+import sys
 from numpy.testing import *
 import numpy.lib.utils as utils
 from numpy.lib import deprecate
 
-from io import StringIO
+if sys.version_info[0] >= 3:
+    from io import StringIO
+else:
+    from StringIO import StringIO
 
 def test_lookfor():
     out = StringIO()
@@ -34,5 +40,9 @@ def test_deprecate_fn():
     assert_('old_func3' in new_func3.__doc__)
     assert_('new_func3' in new_func3.__doc__)
 
+def test_safe_eval_nameconstant():
+    # Test if safe_eval supports Python 3.4 _ast.NameConstant
+    utils.safe_eval('None')
+
 if __name__ == "__main__":
     run_module_suite()
